==> transifex-mobile_0.2-1.tar.gz: transifex-mobile-0.2/_src/opt/transifex-mobile/servers/view.py <==
# -*- coding: utf-8 -*-
from common import QCustomWindow, QIconCache
from gravatar import QGravatar
from PyQt4.QtGui import QGridLayout, QLabel, QPushButton, QScrollArea,\
    QWidget, QAction, QVBoxLayout, QSizePolicy, QToolButton, QListView
from PyQt4.QtCore import QSignalMapper, QString, QSize, QAbstractListModel, QModelIndex
from PyQt4.Qt import Qt, pyqtSlot, SIGNAL, SLOT
from config import config
from projects.view import ProjectsView
from gettextfile.view import FileView
from views.login import LoginDialog
from servers.model import TransifexLoginFailed
from bookmarks.model import BookmarkListModel
try:
    from PyQt4.QtMaemo5 import QMaemo5ValueButton
except ImportError:
    class QMaemo5ValueButton(QPushButton):
        def setValueText(self, secondary):
            self.setText("%s\n%s" % (self.text(), secondary))

class ServerView(QCustomWindow):
    def openProjects(self):
        obj = ProjectsView(self, self.model)
        obj.show()

    @pyqtSlot()
    def updateBookmarks(self):
        self.listviewBookmarks.model().reset()
        
    @pyqtSlot(QModelIndex)
    def openBookmark(self, index):
        remotefile = self.listviewBookmarks.model().data(index)
        obj = FileView(parent=self, fp=remotefile)
        obj.show()
        
    def login(self):
              # Get First name, Surname, E-mail
        d = config.data['servers'][self.model.hostname]
        
        if 'username' in d:
            username = d['username']
        else:
            username = None
            
        if 'password' in d:
            password = d['password']
            remember = True
        else:
            password = None
            remember = False
            
        while True: # Login loop
            try:
                if username and password and self.model.login(username, password):
                    d['username'] = username
                    if remember:
                        d['password'] = password
                    config.save()
                    if not 'profile' in d:
                        d['profile'] = self.model.get_user_info()
                        config.save()
                    return d
            except TransifexLoginFailed:
                pass
            username, password, remember, accepted = LoginDialog.getCredentials(
                server = self.model.hostname,
                username=username, password=password, remember=remember)
            if not accepted:
                self.close()
                break

    def __init__(self, model):
        QCustomWindow.__init__(self,title="",
            skip_central_widget=True,busy=False)
        self.model = model
        self.buttons = []
 
 
        d = self.login() # Show dialog if necessary

 
        layout = QGridLayout(self)
        self.buttonProfile = QMaemo5ValueButton(
            QGravatar(u"%(email)s" % d['profile']),
            u"%(firstname)s %(surname)s" % d['profile'],
            parent = self)
        self.buttonProfile.setValueText(u"%(email)s" % d['profile'])
        layout.addWidget(self.buttonProfile, 0, 0)
            
        
        self.buttonBrowse = QMaemo5ValueButton(
            QIconCache.get("document-open.svgz"), "Browse projects...", parent=self)
        self.buttonBrowse.setValueText("at www.transifex.net")
        self.buttonBrowse.clicked.connect(self.openProjects)
        
        #self.buttonBrowse.clicked.connect(self.updateBookmarks)
        layout.addWidget(self.buttonBrowse, 0, 1)


        m = BookmarkListModel(parent=self, server=self.model)
        self.listviewBookmarks = QListView(self)
        self.listviewBookmarks.setModel(m)
        self.listviewBookmarks.clicked.connect(self.openBookmark)
        layout.addWidget(self.listviewBookmarks , 1, 0, 1, 2)

        self.container = QWidget(self)
        self.container.setLayout(layout)
        
        self.model.locksInvalidated.connect(self.updateBookmarks) # AWESOME

        self.scrollarea = QScrollArea(self)
        self.scrollarea.setWidget(self.container)
        self.scrollarea.setWidgetResizable(True)
        self.setCentralWidget(self.scrollarea)

==> transifex-mobile_0.2-5.tar.gz: transifex-mobile-0.2/_src/opt/transifex-mobile/servers/view.py <==
# -*- coding: utf-8 -*-
from common import QCustomWindow, QIconCache
from gravatar import QGravatar
from PyQt4.QtGui import QGridLayout, QLabel, QPushButton, QScrollArea,\
    QWidget, QAction, QVBoxLayout, QSizePolicy, QToolButton, QListView
from PyQt4.QtCore import QSignalMapper, QString, QSize, QAbstractListModel, QModelIndex
from PyQt4.Qt import Qt
from config import config
from projects.view import ProjectsView
from gettextfile.view import FileView
from views.login import LoginDialog
from servers.model import TransifexLoginFailed
from bookmarks.model import BookmarkListModel
try:
    from PyQt4.QtMaemo5 import QMaemo5ValueButton
except ImportError:
    class QMaemo5ValueButton(QPushButton):
        def setValueText(self, secondary):
            self.setText("%s\n%s" % (self.text(), secondary))

class ServerView(QCustomWindow):
    def openProjects(self):
        obj = ProjectsView(self, self.model)
        obj.show()

    def updateBookmarks(self):
        self.listviewBookmarks.model().reset()
        
    def openBookmark(self, index):
        remotefile = self.listviewBookmarks.model().data(index)
        obj = FileView(parent=self, fp=remotefile)
        obj.show()
        
    def login(self):
              # Get First name, Surname, E-mail
        d = config.data['servers'][self.model.hostname]
        
        if 'username' in d:
            username = d['username']
        else:
            username = None
            
        if 'password' in d:
            password = d['password']
            remember = True
        else:
            password = None
            remember = False
            
        while True: # Login loop
            try:
                if username and password and self.model.login(username, password):
                    d['username'] = username
                    if remember:
                        d['password'] = password
                    config.save()
                    if not 'profile' in d:
                        d['profile'] = self.model.get_user_info()
                        config.save()
                    return d
            except TransifexLoginFailed:
                pass
            username, password, remember, accepted = LoginDialog.getCredentials(
                server = self.model.hostname,
                username=username, password=password, remember=remember)
            if not accepted:
                self.close()
                break

    def __init__(self, model):
        QCustomWindow.__init__(self,title="",
            skip_central_widget=True,busy=False)
        self.model = model
        self.buttons = []
 
 
        d = self.login() # Show dialog if necessary

 
        layout = QGridLayout(self)
        self.buttonProfile = QMaemo5ValueButton(
            QGravatar(u"%(email)s" % d['profile']),
            u"%(firstname)s %(surname)s" % d['profile'],
            parent = self)
        self.buttonProfile.setValueText(u"%(email)s" % d['profile'])
        layout.addWidget(self.buttonProfile, 0, 0)
            
        
        self.buttonBrowse = QMaemo5ValueButton(
            QIconCache.get("document-open.svgz"), "Browse projects...", parent=self)
        self.buttonBrowse.setValueText("at www.transifex.net")
        self.buttonBrowse.clicked.connect(self.openProjects)
        
        #self.buttonBrowse.clicked.connect(self.updateBookmarks)
        layout.addWidget(self.buttonBrowse, 0, 1)


        m = BookmarkListModel(parent=self, server=self.model)
        self.listviewBookmarks = QListView(self)
        self.listviewBookmarks.setModel(m)
        self.listviewBookmarks.clicked.connect(self.openBookmark)
        layout.addWidget(self.listviewBookmarks , 1, 0, 1, 2)

        self.container = QWidget(self)
        self.container.setLayout(layout)
        
        self.model.locksInvalidated.connect(self.updateBookmarks) # AWESOME

        self.scrollarea = QScrollArea(self)
        self.scrollarea.setWidget(self.container)
        self.scrollarea.setWidgetResizable(True)
        self.setCentralWidget(self.scrollarea)
